package com.lframework.xingyun.sc.controller.lend;

import com.lframework.xingyun.sc.bo.lend.tbllendoutreturndetail.GetTblLendOutReturnDetailBo;
import com.lframework.xingyun.sc.bo.lend.tbllendoutreturndetail.QueryTblLendOutReturnDetailBo;
import com.lframework.xingyun.sc.vo.lend.tbllendoutreturndetail.QueryTblLendOutReturnDetailVo;
import com.lframework.xingyun.sc.service.lend.TblLendOutReturnDetailService;
import com.lframework.xingyun.sc.vo.lend.tbllendoutreturndetail.CreateTblLendOutReturnDetailVo;
import com.lframework.xingyun.sc.vo.lend.tbllendoutreturndetail.UpdateTblLendOutReturnDetailVo;
import com.lframework.xingyun.sc.entity.TblLendOutReturnDetail;
import com.lframework.starter.common.constants.StringPool;
import javax.validation.constraints.NotBlank;
import com.lframework.starter.web.resp.InvokeResultBuilder;
import io.swagger.annotations.ApiImplicitParam;
import com.lframework.starter.web.vo.BaseVo;
import com.lframework.starter.web.vo.PageVo;
import com.lframework.starter.web.resp.PageResult;
import javax.validation.constraints.NotNull;
import com.lframework.starter.web.components.validation.IsNumberPrecision;
import com.lframework.starter.web.resp.InvokeResult;
import com.lframework.starter.common.exceptions.impl.DefaultClientException;
import io.swagger.annotations.ApiOperation;
import java.math.BigDecimal;
import com.lframework.starter.web.bo.BaseBo;
import com.lframework.starter.web.utils.IdUtil;
import com.lframework.starter.common.utils.CollectionUtil;
import com.lframework.starter.web.utils.PageResultUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiModelProperty;
import com.lframework.starter.web.components.validation.TypeMismatch;
import org.hibernate.validator.constraints.Length;
import com.lframework.starter.web.controller.DefaultBaseController;
import org.springframework.beans.factory.annotation.Autowired;
import com.lframework.starter.web.annotations.security.HasPermission;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 借转还订单明细 Controller
 *
 * @author Tang,Shuai
 */
@Api(tags = "借转还订单明细")
@Validated
@RestController
@RequestMapping("/lend/tbllendoutreturndetail")
public class TblLendOutReturnDetailController extends DefaultBaseController {

    @Autowired
    private TblLendOutReturnDetailService tblLendOutReturnDetailService;

    /**
     * 查询列表
     */
    @ApiOperation("查询列表")
    @HasPermission({"lend:tbllendoutreturndetail:query"})
    @GetMapping("/query")
    public InvokeResult<PageResult<QueryTblLendOutReturnDetailBo>> query(@Valid QueryTblLendOutReturnDetailVo vo) {

        PageResult<TblLendOutReturnDetail> pageResult = tblLendOutReturnDetailService.query(getPageIndex(vo), getPageSize(vo), vo);

        List<TblLendOutReturnDetail> datas = pageResult.getDatas();
        List<QueryTblLendOutReturnDetailBo> results = null;

        if (!CollectionUtil.isEmpty(datas)) {
            results = datas.stream().map(QueryTblLendOutReturnDetailBo::new).collect(Collectors.toList());
        }

        return InvokeResultBuilder.success(PageResultUtil.rebuild(pageResult, results));
    }

    /**
     * 根据ID查询
     */
    @ApiOperation("根据ID查询")
    @ApiImplicitParam(value = "id", name = "id", paramType = "query", required = true)
    @HasPermission({"lend:tbllendoutreturndetail:query"})
    @GetMapping
    public InvokeResult<GetTblLendOutReturnDetailBo> get(@NotBlank(message = "id不能为空！") String id) {

        TblLendOutReturnDetail data = tblLendOutReturnDetailService.findById(id);
        if (data == null) {
            throw new DefaultClientException("借转还订单明细不存在！");
        }

        GetTblLendOutReturnDetailBo result = new GetTblLendOutReturnDetailBo(data);

        return InvokeResultBuilder.success(result);
    }

    /**
     * 新增
     */
    @ApiOperation("新增")
    @HasPermission({"lend:tbllendoutreturndetail:add"})
    @PostMapping
    public InvokeResult<Void> create(@Valid CreateTblLendOutReturnDetailVo vo) {

        tblLendOutReturnDetailService.create(vo);

        return InvokeResultBuilder.success();
    }

    /**
     * 修改
     */
    @ApiOperation("修改")
    @HasPermission({"lend:tbllendoutreturndetail:modify"})
    @PutMapping
    public InvokeResult<Void> update(@Valid UpdateTblLendOutReturnDetailVo vo) {

        tblLendOutReturnDetailService.update(vo);

        return InvokeResultBuilder.success();
    }
}
