package com.lframework.xingyun.sc.impl.lend;

import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.github.pagehelper.PageInfo;
import com.lframework.xingyun.sc.entity.TblLendOutReturnDetail;
import com.lframework.starter.web.utils.EnumUtil;
import javax.validation.constraints.NotBlank;
import com.lframework.starter.web.service.BaseMpService;
import com.lframework.starter.web.vo.BaseVo;
import com.lframework.starter.common.utils.StringUtil;
import com.lframework.starter.web.vo.PageVo;
import com.lframework.starter.web.resp.PageResult;
import com.lframework.xingyun.template.core.utils.OpLogUtil;
import javax.validation.constraints.NotNull;
import com.lframework.starter.web.components.validation.IsNumberPrecision;
import com.lframework.starter.common.exceptions.impl.DefaultClientException;
import java.math.BigDecimal;
import com.lframework.starter.web.utils.PageHelperUtil;
import com.lframework.starter.web.utils.IdUtil;
import com.lframework.starter.web.utils.PageResultUtil;
import com.lframework.xingyun.template.core.annotations.OpLog;
import com.lframework.starter.common.utils.ObjectUtil;
import com.lframework.starter.web.impl.BaseMpServiceImpl;
import com.lframework.xingyun.template.core.enums.DefaultOpLogType;
import com.lframework.starter.common.utils.Assert;
import io.swagger.annotations.ApiModelProperty;
import com.lframework.starter.web.components.validation.TypeMismatch;
import org.hibernate.validator.constraints.Length;
import com.lframework.xingyun.sc.mappers.TblLendOutReturnDetailMapper;
import com.lframework.xingyun.sc.service.lend.TblLendOutReturnDetailService;
import com.lframework.xingyun.sc.vo.lend.tbllendoutreturndetail.CreateTblLendOutReturnDetailVo;
import com.lframework.xingyun.sc.vo.lend.tbllendoutreturndetail.QueryTblLendOutReturnDetailVo;
import com.lframework.xingyun.sc.vo.lend.tbllendoutreturndetail.UpdateTblLendOutReturnDetailVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cache.annotation.CacheEvict;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Collection;
import java.util.List;

@Service
public class TblLendOutReturnDetailServiceImpl extends BaseMpServiceImpl<TblLendOutReturnDetailMapper, TblLendOutReturnDetail> implements TblLendOutReturnDetailService {

    @Override
    public PageResult<TblLendOutReturnDetail> query(Integer pageIndex, Integer pageSize, QueryTblLendOutReturnDetailVo vo) {

        Assert.greaterThanZero(pageIndex);
        Assert.greaterThanZero(pageSize);

        PageHelperUtil.startPage(pageIndex, pageSize);
        List<TblLendOutReturnDetail> datas = this.query(vo);

        return PageResultUtil.convert(new PageInfo<>(datas));
    }

    @Override
    public List<TblLendOutReturnDetail> query(QueryTblLendOutReturnDetailVo vo) {

        return getBaseMapper().query(vo);
    }

    @Override
    public TblLendOutReturnDetail findById(String id) {

        return getBaseMapper().selectById(id);
    }

    @OpLog(type = 99, name = "新增借转还订单明细，ID：{}", params = {"#id"})
    @Transactional(rollbackFor = Exception.class)
    @Override
    public String create(CreateTblLendOutReturnDetailVo vo) {

        TblLendOutReturnDetail data = new TblLendOutReturnDetail();
        data.setId(IdUtil.getId());
        data.setReturnId(vo.getReturnId());
        data.setProductId(vo.getProductId());
        data.setReturnNum(vo.getReturnNum());
        data.setOriPrice(vo.getOriPrice());
        data.setTaxPrice(vo.getTaxPrice());
        data.setDiscountRate(vo.getDiscountRate());
        data.setIsGift(vo.getIsGift());
        data.setTaxRate(vo.getTaxRate());
        data.setDescription(vo.getDescription());
        data.setOrderNo(vo.getOrderNo());
        data.setSettleStatus(vo.getSettleStatus());

        getBaseMapper().insert(data);

        OpLogUtil.setVariable("id", data.getId());
        OpLogUtil.setExtra(vo);

        return data.getId();
    }

    @OpLog(type = 99, name = "修改借转还订单明细，ID：{}", params = {"#id"})
    @Transactional(rollbackFor = Exception.class)
    @Override
    public void update(UpdateTblLendOutReturnDetailVo vo) {

        TblLendOutReturnDetail data = getBaseMapper().selectById(vo.getId());
        if (ObjectUtil.isNull(data)) {
            throw new DefaultClientException("借转还订单明细不存在！");
        }

        LambdaUpdateWrapper<TblLendOutReturnDetail> updateWrapper = Wrappers.lambdaUpdate(TblLendOutReturnDetail.class)
                .set(TblLendOutReturnDetail::getReturnId, vo.getReturnId())
                .set(TblLendOutReturnDetail::getProductId, vo.getProductId())
                .set(TblLendOutReturnDetail::getReturnNum, vo.getReturnNum())
                .set(TblLendOutReturnDetail::getOriPrice, vo.getOriPrice())
                .set(TblLendOutReturnDetail::getTaxPrice, vo.getTaxPrice())
                .set(TblLendOutReturnDetail::getDiscountRate, vo.getDiscountRate())
                .set(TblLendOutReturnDetail::getIsGift, vo.getIsGift())
                .set(TblLendOutReturnDetail::getTaxRate, vo.getTaxRate())
                .set(TblLendOutReturnDetail::getDescription, vo.getDescription())
                .set(TblLendOutReturnDetail::getOrderNo, vo.getOrderNo())
                .set(TblLendOutReturnDetail::getSettleStatus, vo.getSettleStatus())
                .eq(TblLendOutReturnDetail::getId, vo.getId());

        getBaseMapper().update(updateWrapper);

        OpLogUtil.setVariable("id", data.getId());
        OpLogUtil.setExtra(vo);
    }

    @Override
    public void cleanCacheByKey(Serializable key) {

    }
}
