package com.lframework.xingyun.sc.vo.lend.tbllendoutreturndetail;

import java.math.BigDecimal;
import javax.validation.constraints.NotBlank;
import com.lframework.starter.web.utils.IdUtil;
import com.lframework.starter.web.vo.BaseVo;
import javax.validation.constraints.NotNull;
import com.lframework.starter.web.components.validation.IsNumberPrecision;
import io.swagger.annotations.ApiModelProperty;
import com.lframework.starter.web.components.validation.TypeMismatch;
import org.hibernate.validator.constraints.Length;
import java.io.Serializable;
import lombok.Data;

@Data
public class CreateTblLendOutReturnDetailVo implements BaseVo, Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 退货单ID
     */
    @ApiModelProperty(value = "退货单ID", required = true)
    @NotBlank(message = "请输入退货单ID！")
    @Length(message = "退货单ID最多允许32个字符！")
    private String returnId;

    /**
     * 商品ID
     */
    @ApiModelProperty(value = "商品ID", required = true)
    @NotBlank(message = "请输入商品ID！")
    @Length(message = "商品ID最多允许32个字符！")
    private String productId;

    /**
     * 退货数量
     */
    @ApiModelProperty(value = "退货数量", required = true)
    @NotNull(message = "请输入退货数量！")
    @TypeMismatch(message = "退货数量格式有误！")
    private Integer returnNum;

    /**
     * 原价
     */
    @ApiModelProperty(value = "原价", required = true)
    @NotNull(message = "请输入原价！")
    @TypeMismatch(message = "原价格式有误！")
    @IsNumberPrecision(message = "原价最多允许2位小数！", value = 2)
    private BigDecimal oriPrice;

    /**
     * 现价
     */
    @ApiModelProperty(value = "现价", required = true)
    @NotNull(message = "请输入现价！")
    @TypeMismatch(message = "现价格式有误！")
    @IsNumberPrecision(message = "现价最多允许2位小数！", value = 2)
    private BigDecimal taxPrice;

    /**
     * 折扣率（%）
     */
    @ApiModelProperty(value = "折扣率（%）", required = true)
    @NotNull(message = "请输入折扣率（%）！")
    @TypeMismatch(message = "折扣率（%）格式有误！")
    @IsNumberPrecision(message = "折扣率（%）最多允许2位小数！", value = 2)
    private BigDecimal discountRate;

    /**
     * 是否赠品
     */
    @ApiModelProperty(value = "是否赠品", required = true)
    @NotNull(message = "请输入是否赠品！")
    @TypeMismatch(message = "是否赠品格式有误！")
    private Integer isGift;

    /**
     * 税率（%）
     */
    @ApiModelProperty(value = "税率（%）", required = true)
    @NotNull(message = "请输入税率（%）！")
    @TypeMismatch(message = "税率（%）格式有误！")
    @IsNumberPrecision(message = "税率（%）最多允许2位小数！", value = 2)
    private BigDecimal taxRate;

    /**
     * 备注
     */
    @ApiModelProperty(value = "备注", required = true)
    @NotBlank(message = "请输入备注！")
    @Length(message = "备注最多允许200个字符！")
    private String description;

    /**
     * 排序编号
     */
    @ApiModelProperty(value = "排序编号", required = true)
    @NotNull(message = "请输入排序编号！")
    @TypeMismatch(message = "排序编号格式有误！")
    private Integer orderNo;

    /**
     * 结算状态
     */
    @ApiModelProperty(value = "结算状态", required = true)
    @NotNull(message = "请输入结算状态！")
    @TypeMismatch(message = "结算状态格式有误！")
    private Integer settleStatus;

}
