package com.ruoyi.model.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.AppUsers;
import com.ruoyi.model.service.IAppUsersService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 用户Controller
 * 
 * @author ruoyi
 * @date 2025-03-27
 */
@RestController
@RequestMapping("/model/AppUsers")
public class AppUsersController extends BaseController
{
    @Autowired
    private IAppUsersService appUsersService;

    /**
     * 查询用户列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppUsers:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppUsers appUsers)
    {
        startPage();
        List<AppUsers> list = appUsersService.selectAppUsersList(appUsers);
        return getDataTable(list);
    }

    /**
     * 导出用户列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppUsers:export')")
    @Log(title = "用户", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppUsers appUsers) throws IOException {
        List<AppUsers> list = appUsersService.selectAppUsersList(appUsers);
        ExcelUtil<AppUsers> util = new ExcelUtil<AppUsers>(AppUsers.class);
        util.exportExcel(response, list, "用户数据");
    }

    /**
     * 获取用户详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppUsers:query')")
    @GetMapping(value = "/{userId}")
    public AjaxResult getInfo(@PathVariable("userId") Long userId)
    {
        return success(appUsersService.selectAppUsersByUserId(userId));
    }

    /**
     * 新增用户
     */
    @PreAuthorize("@ss.hasPermi('model:AppUsers:add')")
    @Log(title = "用户", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppUsers appUsers)
    {
        return toAjax(appUsersService.insertAppUsers(appUsers));
    }

    /**
     * 修改用户
     */
    @PreAuthorize("@ss.hasPermi('model:AppUsers:edit')")
    @Log(title = "用户", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppUsers appUsers)
    {
        return toAjax(appUsersService.updateAppUsers(appUsers));
    }

    /**
     * 删除用户
     */
    @PreAuthorize("@ss.hasPermi('model:AppUsers:remove')")
    @Log(title = "用户", businessType = BusinessType.DELETE)
	@DeleteMapping("/{userIds}")
    public AjaxResult remove(@PathVariable Long[] userIds)
    {
        return toAjax(appUsersService.deleteAppUsersByUserIds(userIds));
    }
}
