package com.ruoyi.model.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.AppletAddress;
import com.ruoyi.model.service.IAppletAddressService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 地址信息Controller
 * 
 * @author ruoyi
 * @date 2025-03-28
 */
@RestController
@RequestMapping("/model/AppletAddress")
public class AppletAddressController extends BaseController
{
    @Autowired
    private IAppletAddressService appletAddressService;

    /**
     * 查询地址信息列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletAddress:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppletAddress appletAddress)
    {
        startPage();
        List<AppletAddress> list = appletAddressService.selectAppletAddressList(appletAddress);
        return getDataTable(list);
    }

//    /**
//     * 导出地址信息列表
//     */
//    @PreAuthorize("@ss.hasPermi('model:AppletAddress:export')")
//    @Log(title = "地址信息", businessType = BusinessType.EXPORT)
//    @PostMapping("/export")
//    public void export(HttpServletResponse response, AppletAddress appletAddress)
//    {
//        List<AppletAddress> list = appletAddressService.selectAppletAddressList(appletAddress);
//        ExcelUtil<AppletAddress> util = new ExcelUtil<AppletAddress>(AppletAddress.class);
//        util.exportExcel(response, list, "地址信息数据");
//    }

    /**
     * 获取地址信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppletAddress:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(appletAddressService.selectAppletAddressById(id));
    }

    /**
     * 新增地址信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppletAddress:add')")
    @Log(title = "地址信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppletAddress appletAddress)
    {
        return toAjax(appletAddressService.insertAppletAddress(appletAddress));
    }

    /**
     * 修改地址信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppletAddress:edit')")
    @Log(title = "地址信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppletAddress appletAddress)
    {
        return toAjax(appletAddressService.updateAppletAddress(appletAddress));
    }

    /**
     * 删除地址信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppletAddress:remove')")
    @Log(title = "地址信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(appletAddressService.deleteAppletAddressByIds(ids));
    }
}
