package com.ruoyi.model.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.AppletAnswerTrain;
import com.ruoyi.model.service.IAppletAnswerTrainService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 用户培训考核答案Controller
 * 
 * @author ruoyi
 * @date 2025-03-28
 */
@RestController
@RequestMapping("/model/AppletAnswerTrain")
public class AppletAnswerTrainController extends BaseController
{
    @Autowired
    private IAppletAnswerTrainService appletAnswerTrainService;

    /**
     * 查询用户培训考核答案列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletAnswerTrain:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppletAnswerTrain appletAnswerTrain)
    {
        startPage();
        List<AppletAnswerTrain> list = appletAnswerTrainService.selectAppletAnswerTrainList(appletAnswerTrain);
        return getDataTable(list);
    }

    /**
     * 导出用户培训考核答案列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletAnswerTrain:export')")
    @Log(title = "用户培训考核答案", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppletAnswerTrain appletAnswerTrain) throws IOException {
        List<AppletAnswerTrain> list = appletAnswerTrainService.selectAppletAnswerTrainList(appletAnswerTrain);
        ExcelUtil<AppletAnswerTrain> util = new ExcelUtil<AppletAnswerTrain>(AppletAnswerTrain.class);
        util.exportExcel(response, list, "用户培训考核答案数据");
    }

    /**
     * 获取用户培训考核答案详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppletAnswerTrain:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(appletAnswerTrainService.selectAppletAnswerTrainById(id));
    }

    /**
     * 新增用户培训考核答案
     */
    @PreAuthorize("@ss.hasPermi('model:AppletAnswerTrain:add')")
    @Log(title = "用户培训考核答案", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppletAnswerTrain appletAnswerTrain)
    {
        return toAjax(appletAnswerTrainService.insertAppletAnswerTrain(appletAnswerTrain));
    }

    /**
     * 修改用户培训考核答案
     */
    @PreAuthorize("@ss.hasPermi('model:AppletAnswerTrain:edit')")
    @Log(title = "用户培训考核答案", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppletAnswerTrain appletAnswerTrain)
    {
        return toAjax(appletAnswerTrainService.updateAppletAnswerTrain(appletAnswerTrain));
    }

    /**
     * 删除用户培训考核答案
     */
    @PreAuthorize("@ss.hasPermi('model:AppletAnswerTrain:remove')")
    @Log(title = "用户培训考核答案", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(appletAnswerTrainService.deleteAppletAnswerTrainByIds(ids));
    }
}
