package com.ruoyi.model.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.AppletIcon;
import com.ruoyi.model.service.IAppletIconService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 跳转图标菜单Controller
 * 
 * @author ruoyi
 * @date 2025-03-30
 */
@RestController
@RequestMapping("/model/AppletIcon")
public class AppletIconController extends BaseController
{
    @Autowired
    private IAppletIconService appletIconService;

    /**
     * 查询跳转图标菜单列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletIcon:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppletIcon appletIcon)
    {
        startPage();
        List<AppletIcon> list = appletIconService.selectAppletIconList(appletIcon);
        return getDataTable(list);
    }

    /**
     * 导出跳转图标菜单列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletIcon:export')")
    @Log(title = "跳转图标菜单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppletIcon appletIcon) throws IOException {
        List<AppletIcon> list = appletIconService.selectAppletIconList(appletIcon);
        ExcelUtil<AppletIcon> util = new ExcelUtil<AppletIcon>(AppletIcon.class);
        util.exportExcel(response, list, "跳转图标菜单数据");
    }

    /**
     * 获取跳转图标菜单详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppletIcon:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(appletIconService.selectAppletIconById(id));
    }

    /**
     * 新增跳转图标菜单
     */
    @PreAuthorize("@ss.hasPermi('model:AppletIcon:add')")
    @Log(title = "跳转图标菜单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppletIcon appletIcon)
    {
        return toAjax(appletIconService.insertAppletIcon(appletIcon));
    }

    /**
     * 修改跳转图标菜单
     */
    @PreAuthorize("@ss.hasPermi('model:AppletIcon:edit')")
    @Log(title = "跳转图标菜单", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppletIcon appletIcon)
    {
        return toAjax(appletIconService.updateAppletIcon(appletIcon));
    }

    /**
     * 删除跳转图标菜单
     */
    @PreAuthorize("@ss.hasPermi('model:AppletIcon:remove')")
    @Log(title = "跳转图标菜单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(appletIconService.deleteAppletIconByIds(ids));
    }
}
