package com.ruoyi.model.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.AppletIncrease;
import com.ruoyi.model.service.IAppletIncreaseService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 增值服务Controller
 * 
 * @author ruoyi
 * @date 2025-03-28
 */
@RestController
@RequestMapping("/model/AppletIncrease")
public class AppletIncreaseController extends BaseController
{
    @Autowired
    private IAppletIncreaseService appletIncreaseService;

    /**
     * 查询增值服务列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletIncrease:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppletIncrease appletIncrease)
    {
        startPage();
        List<AppletIncrease> list = appletIncreaseService.selectAppletIncreaseList(appletIncrease);
        return getDataTable(list);
    }

    /**
     * 导出增值服务列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletIncrease:export')")
    @Log(title = "增值服务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppletIncrease appletIncrease) throws IOException {
        List<AppletIncrease> list = appletIncreaseService.selectAppletIncreaseList(appletIncrease);
        ExcelUtil<AppletIncrease> util = new ExcelUtil<AppletIncrease>(AppletIncrease.class);
        util.exportExcel(response, list, "增值服务数据");
    }

    /**
     * 获取增值服务详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppletIncrease:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(appletIncreaseService.selectAppletIncreaseById(id));
    }

    /**
     * 新增增值服务
     */
    @PreAuthorize("@ss.hasPermi('model:AppletIncrease:add')")
    @Log(title = "增值服务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppletIncrease appletIncrease)
    {
        return toAjax(appletIncreaseService.insertAppletIncrease(appletIncrease));
    }

    /**
     * 修改增值服务
     */
    @PreAuthorize("@ss.hasPermi('model:AppletIncrease:edit')")
    @Log(title = "增值服务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppletIncrease appletIncrease)
    {
        return toAjax(appletIncreaseService.updateAppletIncrease(appletIncrease));
    }

    /**
     * 删除增值服务
     */
    @PreAuthorize("@ss.hasPermi('model:AppletIncrease:remove')")
    @Log(title = "增值服务", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(appletIncreaseService.deleteAppletIncreaseByIds(ids));
    }
}
