package com.ruoyi.model.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.AppletLicense;
import com.ruoyi.model.service.IAppletLicenseService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 专业执照信息Controller
 * 
 * @author ruoyi
 * @date 2025-03-28
 */
@RestController
@RequestMapping("/model/AppletLicense")
public class AppletLicenseController extends BaseController
{
    @Autowired
    private IAppletLicenseService appletLicenseService;

    /**
     * 查询专业执照信息列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletLicense:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppletLicense appletLicense)
    {
        startPage();
        List<AppletLicense> list = appletLicenseService.selectAppletLicenseList(appletLicense);
        return getDataTable(list);
    }

    /**
     * 导出专业执照信息列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletLicense:export')")
    @Log(title = "专业执照信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppletLicense appletLicense) throws IOException {
        List<AppletLicense> list = appletLicenseService.selectAppletLicenseList(appletLicense);
        ExcelUtil<AppletLicense> util = new ExcelUtil<AppletLicense>(AppletLicense.class);
        util.exportExcel(response, list, "专业执照信息数据");
    }

    /**
     * 获取专业执照信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppletLicense:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(appletLicenseService.selectAppletLicenseById(id));
    }

    /**
     * 新增专业执照信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppletLicense:add')")
    @Log(title = "专业执照信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppletLicense appletLicense)
    {
        return toAjax(appletLicenseService.insertAppletLicense(appletLicense));
    }

    /**
     * 修改专业执照信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppletLicense:edit')")
    @Log(title = "专业执照信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppletLicense appletLicense)
    {
        return toAjax(appletLicenseService.updateAppletLicense(appletLicense));
    }

    /**
     * 删除专业执照信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppletLicense:remove')")
    @Log(title = "专业执照信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(appletLicenseService.deleteAppletLicenseByIds(ids));
    }
}
