package com.ruoyi.model.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.AppletOrderItemDate;
import com.ruoyi.model.service.IAppletOrderItemDateService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 订单信息表Controller
 *
 * @author daixiande
 * @date 2025-04-14
 */
@RestController
@RequestMapping("/model/AppletOrderItemDate")
public class AppletOrderItemDateController extends BaseController {
    @Autowired
    private IAppletOrderItemDateService appletOrderItemDateService;

    /**
     * 查询订单信息表列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletOrderItemDate:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppletOrderItemDate appletOrderItemDate) {
        startPage();
        List<AppletOrderItemDate> list = appletOrderItemDateService.selectAppletOrderItemDateList(appletOrderItemDate);
        return getDataTable(list);
    }

    /**
     * 导出订单信息表列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletOrderItemDate:export')")
    @Log(title = "订单信息表", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(AppletOrderItemDate appletOrderItemDate) {
        List<AppletOrderItemDate> list = appletOrderItemDateService.selectAppletOrderItemDateList(appletOrderItemDate);
        ExcelUtil<AppletOrderItemDate> util = new ExcelUtil<AppletOrderItemDate>(AppletOrderItemDate.class);
        return util.exportExcel(list, "订单信息表数据");
    }

    /**
     * 获取订单信息表详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppletOrderItemDate:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return AjaxResult.success(appletOrderItemDateService.selectAppletOrderItemDateById(id));
    }

    /**
     * 新增订单信息表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletOrderItemDate:add')")
    @Log(title = "订单信息表", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppletOrderItemDate appletOrderItemDate) {
        return toAjax(appletOrderItemDateService.insertAppletOrderItemDate(appletOrderItemDate));
    }

    /**
     * 修改订单信息表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletOrderItemDate:edit')")
    @Log(title = "订单信息表", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppletOrderItemDate appletOrderItemDate) {
        return toAjax(appletOrderItemDateService.updateAppletOrderItemDate(appletOrderItemDate));
    }

    /**
     * 删除订单信息表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletOrderItemDate:remove')")
    @Log(title = "订单信息表", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(appletOrderItemDateService.deleteAppletOrderItemDateByIds(ids));
    }
}
