package com.ruoyi.model.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.AppletOrderItemDateLog;
import com.ruoyi.model.service.IAppletOrderItemDateLogService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 订单信息表Controller
 *
 * @author daixiande
 * @date 2025-04-14
 */
@RestController
@RequestMapping("/model/AppletOrderItemDateLog")
public class AppletOrderItemDateLogController extends BaseController {
    @Autowired
    private IAppletOrderItemDateLogService appletOrderItemDateLogService;

    /**
     * 查询订单信息表列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletOrderItemDateLog:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppletOrderItemDateLog appletOrderItemDateLog) {
        startPage();
        List<AppletOrderItemDateLog> list = appletOrderItemDateLogService.selectAppletOrderItemDateLogList(appletOrderItemDateLog);
        return getDataTable(list);
    }

    /**
     * 导出订单信息表列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletOrderItemDateLog:export')")
    @Log(title = "订单信息表", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(AppletOrderItemDateLog appletOrderItemDateLog) {
        List<AppletOrderItemDateLog> list = appletOrderItemDateLogService.selectAppletOrderItemDateLogList(appletOrderItemDateLog);
        ExcelUtil<AppletOrderItemDateLog> util = new ExcelUtil<AppletOrderItemDateLog>(AppletOrderItemDateLog.class);
        return util.exportExcel(list, "订单信息表数据");
    }

    /**
     * 获取订单信息表详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppletOrderItemDateLog:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return AjaxResult.success(appletOrderItemDateLogService.selectAppletOrderItemDateLogById(id));
    }

    /**
     * 新增订单信息表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletOrderItemDateLog:add')")
    @Log(title = "订单信息表", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppletOrderItemDateLog appletOrderItemDateLog) {
        return toAjax(appletOrderItemDateLogService.insertAppletOrderItemDateLog(appletOrderItemDateLog));
    }

    /**
     * 修改订单信息表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletOrderItemDateLog:edit')")
    @Log(title = "订单信息表", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppletOrderItemDateLog appletOrderItemDateLog) {
        return toAjax(appletOrderItemDateLogService.updateAppletOrderItemDateLog(appletOrderItemDateLog));
    }

    /**
     * 删除订单信息表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletOrderItemDateLog:remove')")
    @Log(title = "订单信息表", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(appletOrderItemDateLogService.deleteAppletOrderItemDateLogByIds(ids));
    }
}
