package com.ruoyi.model.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.AppletOutDate;
import com.ruoyi.model.service.IAppletOutDateService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 不接单日期Controller
 * 
 * @author ruoyi
 * @date 2025-03-28
 */
@RestController
@RequestMapping("/model/AppletOutDate")
public class AppletOutDateController extends BaseController
{
    @Autowired
    private IAppletOutDateService appletOutDateService;

    /**
     * 查询不接单日期列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletOutDate:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppletOutDate appletOutDate)
    {
        startPage();
        List<AppletOutDate> list = appletOutDateService.selectAppletOutDateList(appletOutDate);
        return getDataTable(list);
    }

    /**
     * 导出不接单日期列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletOutDate:export')")
    @Log(title = "不接单日期", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppletOutDate appletOutDate) throws IOException {
        List<AppletOutDate> list = appletOutDateService.selectAppletOutDateList(appletOutDate);
        ExcelUtil<AppletOutDate> util = new ExcelUtil<AppletOutDate>(AppletOutDate.class);
        util.exportExcel(response, list, "不接单日期数据");
    }

    /**
     * 获取不接单日期详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppletOutDate:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(appletOutDateService.selectAppletOutDateById(id));
    }

    /**
     * 新增不接单日期
     */
    @PreAuthorize("@ss.hasPermi('model:AppletOutDate:add')")
    @Log(title = "不接单日期", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppletOutDate appletOutDate)
    {
        return toAjax(appletOutDateService.insertAppletOutDate(appletOutDate));
    }

    /**
     * 修改不接单日期
     */
    @PreAuthorize("@ss.hasPermi('model:AppletOutDate:edit')")
    @Log(title = "不接单日期", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppletOutDate appletOutDate)
    {
        return toAjax(appletOutDateService.updateAppletOutDate(appletOutDate));
    }

    /**
     * 删除不接单日期
     */
    @PreAuthorize("@ss.hasPermi('model:AppletOutDate:remove')")
    @Log(title = "不接单日期", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(appletOutDateService.deleteAppletOutDateByIds(ids));
    }
}
