package com.ruoyi.model.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.AppletService;
import com.ruoyi.model.service.IAppletServiceService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 平台&服务介绍信息Controller
 * 
 * @author ruoyi
 * @date 2025-03-28
 */
@RestController
@RequestMapping("/model/AppletService")
public class AppletServiceController extends BaseController
{
    @Autowired
    private IAppletServiceService appletServiceService;

    /**
     * 查询平台&服务介绍信息列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletService:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppletService appletService)
    {
        startPage();
        List<AppletService> list = appletServiceService.selectAppletServiceList(appletService);
        return getDataTable(list);
    }

    /**
     * 导出平台&服务介绍信息列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletService:export')")
    @Log(title = "平台&服务介绍信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppletService appletService)
    {
//        List<AppletService> list = appletServiceService.selectAppletServiceList(appletService);
//        ExcelUtil<AppletService> util = new ExcelUtil<AppletService>(AppletService.class);
//        util.exportExcel(response, list, "平台&服务介绍信息数据");
    }

    /**
     * 获取平台&服务介绍信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppletService:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(appletServiceService.selectAppletServiceById(id));
    }

    /**
     * 新增平台&服务介绍信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppletService:add')")
    @Log(title = "平台&服务介绍信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppletService appletService)
    {
        return toAjax(appletServiceService.insertAppletService(appletService));
    }

    /**
     * 修改平台&服务介绍信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppletService:edit')")
    @Log(title = "平台&服务介绍信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppletService appletService)
    {
        return toAjax(appletServiceService.updateAppletService(appletService));
    }

    /**
     * 删除平台&服务介绍信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppletService:remove')")
    @Log(title = "平台&服务介绍信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(appletServiceService.deleteAppletServiceByIds(ids));
    }
}
