package com.cyl.manager.ums.service;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.cyl.manager.ums.domain.Pet;
import com.cyl.manager.ums.mapper.PetMapper;
import com.cyl.manager.ums.pojo.query.PetQuery;
import com.cyl.manager.ums.pojo.vo.PetVO;
import com.cyl.manager.ums.convert.PetConvert;
import com.github.pagehelper.PageHelper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.time.LocalDateTime;
import java.util.List;

/**
 * 宠物档案Service接口
 *
 * @author daixiande
 */
@Service
public class PetService {

    @Autowired
    private PetMapper petMapper;

    @Autowired
    private PetConvert convert;
    /**
     * 查询宠物档案
     *
     * @param id 宠物档案主键
     * @return 宠物档案
     */
    public PetVO selectPetById(Integer id){
        Pet pet = petMapper.selectById(id);
        PetVO petVO = convert.do2vo(pet);
        return petVO;
    }

    /**
     * 导出宠物档案列表
     *
     * @param pet 宠物档案
     * @return 宠物档案集合
     */
    public List<Pet> selectPetList(Pet pet){
        QueryWrapper<Pet> dd = new QueryWrapper<>();
        dd.eq("del_flag",0);
        if(!StringUtils.isEmpty(pet.getName())){
            dd.eq("name",pet.getName());
        }
        if(!StringUtils.isEmpty(pet.getPetType())){
            dd.eq("pet_type",pet.getPetType());
        }
        if(!StringUtils.isEmpty(pet.getGender())){
            dd.eq("gender",pet.getGender());
        }
        if(!StringUtils.isEmpty(pet.getBirthDate())){
            dd.eq("birth_date",pet.getBirthDate());
        }
        if(!StringUtils.isEmpty(pet.getBreed())){
            dd.eq("breed",pet.getBreed());
        }
        if(!StringUtils.isEmpty(pet.getBodyType())){
            dd.eq("body_type",pet.getBodyType());
        }
        return petMapper.selectList(dd);
    }

    /**
     * 新增宠物档案
     *
     * @param petVO 宠物档案
     * @return 结果
     */
    public int insertPet(PetVO petVO){
        Pet pet = convert.vo2do(petVO);
        petMapper.insert(pet);
        return 1;
    }

    /**
     * 修改宠物档案
     *
     * @param petVO 宠物档案
     * @return 结果
     */
    public int updatePet(PetVO petVO){
        Pet pet = convert.vo2do(petVO);
        pet.setUpdateTime(LocalDateTime.now());
        return petMapper.updateById(pet);
    }

    /**
     * 批量删除宠物档案
     *
     * @param ids 需要删除的宠物档案主键集合
     * @return 结果
     */
    public int deletePetByIds(Integer[] ids){
        return petMapper.deleteByIds(ids);
    }

    /**
     * 查询宠物档案列表
     *
     * @param query query
     * @param page page
     * @return 宠物档案集合
     */
    public List<Pet> selectList(PetQuery query, Pageable page){
        if (page != null) {
            PageHelper.startPage(page.getPageNumber() + 1, page.getPageSize());
        }
        QueryWrapper<Pet> dd = new QueryWrapper<>();
        dd.eq("del_flag",0);
        if(!StringUtils.isEmpty(query.getName())){
            dd.eq("name",query.getName());
        }
        if(!StringUtils.isEmpty(query.getPetType())){
            dd.eq("pet_type",query.getPetType());
        }
        if(!StringUtils.isEmpty(query.getGender())){
            dd.eq("gender",query.getGender());
        }
        if(!StringUtils.isEmpty(query.getBirthDate())){
            dd.eq("birth_date",query.getBirthDate());
        }
        if(!StringUtils.isEmpty(query.getBreed())){
            dd.eq("breed",query.getBreed());
        }
        if(!StringUtils.isEmpty(query.getBodyType())){
            dd.eq("body_type",query.getBodyType());
        }
        return petMapper.selectList(dd);
    }

}
