import { defHttp } from '/@/utils/http/axios';
import { PageResult } from '@/api/model/pageResult';
import { ContentTypeEnum } from '@/enums/httpEnum';
import { QueryTblLendOutReturnDetailVo } from '@/api/lend/tbllendoutreturndetail/model/queryTblLendOutReturnDetailVo';
import { QueryTblLendOutReturnDetailBo } from '@/api/lend/tbllendoutreturndetail/model/queryTblLendOutReturnDetailBo';
import { GetTblLendOutReturnDetailBo } from '@/api/lend/tbllendoutreturndetail/model/getTblLendOutReturnDetailBo';
import { CreateTblLendOutReturnDetailVo } from '@/api/lend/tbllendoutreturndetail/model/createTblLendOutReturnDetailVo';
import { UpdateTblLendOutReturnDetailVo } from '@/api/lend/tbllendoutreturndetail/model/updateTblLendOutReturnDetailVo';

const baseUrl = '/lend/tbllendoutreturndetail';
const region = 'cloud-api';

/**
 * 查询列表
 * @param params
 * @returns {Promise}
 */
export function query(params: QueryTblLendOutReturnDetailVo): Promise<PageResult<QueryTblLendOutReturnDetailBo>> {
  return defHttp.get<PageResult<QueryTblLendOutReturnDetailBo>>(
    {
      url: baseUrl + '/query',
      params: params,
    },
    {
      region,
    },
  );
}

/**
 * 根据ID查询
 * @param id
 * @returns {Promise}
 */
export function get(id: String): Promise<GetTblLendOutReturnDetailBo> {
  return defHttp.get<GetTblLendOutReturnDetailBo>(
    {
      url: baseUrl,
      params: {
        id,
      }
    },
    {
      region,
    },
  );
}

/**
 * 新增
 * @param params
 * @returns {Promise}
 */
export function create(params: CreateTblLendOutReturnDetailVo): Promise<void> {
  return defHttp.post<void>(
    {
      url: baseUrl,
      data: params,
    },
    {
      contentType: ContentTypeEnum.FORM_URLENCODED,
      region,
    },
  );
}

/**
 * 修改
 * @param params
 * @returns {Promise}
 */
export function update(params: UpdateTblLendOutReturnDetailVo): Promise<void> {
  return defHttp.put<void>(
    {
      url: baseUrl,
      data: params,
    },
    {
      contentType: ContentTypeEnum.FORM_URLENCODED,
      region,
    },
  );
}

